==> kwooty-0.4.0.tar.gz: kwooty-0.4.0/src/segmentdecoderuuenc.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Xavier Lefage                                   *
 *   xavier.kwooty@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef SEGMENTDECODERUUENC_H
#define SEGMENTDECODERUUENC_H

#include "segmentdecoderbase.h"

class SegmentDecoderUUEnc : public SegmentDecoderBase
{

    Q_OBJECT

public:
    SegmentDecoderUUEnc();
    ~SegmentDecoderUUEnc();


private:
    enum UUValues {
                    UUMaxDecodedLineSize = 45,
                    UUMaxEncodedLineSize = 61
                  };

    void decodeEncodedData(QFile&, SegmentData&, int&, const QByteArray& , bool&, bool&);
    QString searchPattern(QFile& segmentFile);
    bool decodeUUenc(const QByteArray&, QFile&, const int&);
    bool isUUEncodedLine(QByteArray&);


signals:

public slots:

private slots:


};

#endif // SEGMENTDECODERUUENC_H

==> kwooty-0.6.3.tar.gz: kwooty-0.6.3/src/segmentdecoderuuenc.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Xavier Lefage                                   *
 *   xavier.kwooty@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifndef SEGMENTDECODERUUENC_H
#define SEGMENTDECODERUUENC_H

#include "segmentdecoderbase.h"

class SegmentDecoderUUEnc : public SegmentDecoderBase
{

    Q_OBJECT

public:
    SegmentDecoderUUEnc(SegmentsDecoderThread*);
    ~SegmentDecoderUUEnc();


private:
    enum UUValues {
                    UUMaxDecodedLineSize = 45,
                    UUMaxEncodedLineSize = 61
                  };

    void decodeEncodedData(QFile&, SegmentData&, int&, const QByteArray& , bool&, bool&);
    QString searchPattern(QFile& segmentFile);
    bool decodeUUenc(const QByteArray&, QFile&, const int&);
    bool isUUEncodedLine(QByteArray&);
    void decodeProgression(const int, UtilityNamespace::ItemStatus, const QString& decodedFileName = QString());


signals:

public slots:

private slots:


};

#endif // SEGMENTDECODERUUENC_H
